@@ -10,6 +10,7 @@ import os
 import yaml
 from deepcinac.utils.signal import smooth_convolve
 import hdf5storage
+from scipy.stats import wilcoxon
 
 
 def build_spike_nums_dur(spike_nums, peak_nums, traces=None, fluorescence_threshold=None):
@@ -783,6 +784,10 @@ class CinacBenchmarks:
                                 box_plots_labels=None,
                                 colorfull=True,
                                 white_background=True,
+                                stats_to_show=("sensitivity", "specificity", "PPV", "NPV"),
+                                title_correspondance=None,
+                                alpha_scatter=1.,
+                                put_metric_as_y_axis_label=False,
                                 save_formats="pdf", dpi=500):
         """
 
@@ -793,20 +798,41 @@ class CinacBenchmarks:
         The labels should be existing one, otherwise it will crash
         :param with_cells: if True, display a scatter for each cell
         :param save_formats:
+        :param title_correspondance: dict or None, keys are the stats to show, and the value is another string
+        that will be displayed in the title
         :return:
         """
         result_dict_to_use = self.results_frames_dict
         if not for_frames:
             result_dict_to_use = self.results_transients_dict
-        stats_to_show = ["sensitivity", "specificity", "PPV", "NPV"]
 
-        stat_fig, axes = plt.subplots(nrows=2, ncols=2, squeeze=True,
-                                      gridspec_kw={'height_ratios': [0.5, 0.5],
-                                                   'width_ratios': [0.5, 0.5]},
-                                      figsize=(10, 10), dpi=dpi)
+        nrows = 2
+        height_ratios = [0.5, 0.5]
+        ncols = 2
+        width_ratios = [0.5, 0.5]
+        figsize = (10, 10)
+        if len(stats_to_show) == 2:
+            nrows = 2
+            height_ratios = [0.5, 0.5]
+            ncols = 1
+            width_ratios = [1]
+            figsize = (5, 10)
+        if len(stats_to_show) == 1:
+            nrows = 1
+            height_ratios = [1]
+            ncols = 1
+            width_ratios = [1]
+            figsize = (5, 5)
+        stat_fig, axes = plt.subplots(nrows=nrows, ncols=ncols, squeeze=True,
+                                      gridspec_kw={'height_ratios': height_ratios,
+                                                   'width_ratios': width_ratios},
+                                      figsize=figsize, dpi=dpi)
 
         stat_fig.set_tight_layout({'rect': [0, 0, 1, 1], 'pad': 1, 'w_pad': 1, 'h_pad': 5})
-        axes = np.ndarray.flatten(axes)
+        if isinstance(axes, np.ndarray):
+            axes = np.ndarray.flatten(axes)
+        else:
+            axes = [axes]
         fig_patch = stat_fig.patch
 
         # rgba = c_map(0)
@@ -854,7 +880,7 @@ class CinacBenchmarks:
                             else:
                                 edgecolors = "white"
                             if color_cell_as_boxplot:
-                                color_cell = self.colors_boxplots[label_index%len(self.colors_boxplots)]
+                                color_cell = self.colors_boxplots[label_index % len(self.colors_boxplots)]
                             elif session_id not in self.cells_to_color:
                                 color_cell = BREWER_COLORS[label_index % len(BREWER_COLORS)]
                             else:
@@ -863,7 +889,7 @@ class CinacBenchmarks:
                                        color=color_cell,
                                        marker="o",
                                        edgecolors=edgecolors,
-                                       s=60, zorder=21, alpha=0.4)
+                                       s=60, zorder=21, alpha=alpha_scatter)
                             if cell_to_display > 999:
                                 font_size = 2
                             ax.text(x=x_pos, y=y_pos,
@@ -905,9 +931,9 @@ class CinacBenchmarks:
             ax.xaxis.label.set_color(text_color)
             ax.tick_params(axis='x', colors=text_color)
             if n_box_plots <= 2:
-                ax.xaxis.set_tick_params(labelsize=15)
+                ax.xaxis.set_tick_params(labelsize=20)
             elif n_box_plots <= 6:
-                ax.xaxis.set_tick_params(labelsize=9)
+                ax.xaxis.set_tick_params(labelsize=15)
             else:
                 ax.xaxis.set_tick_params(labelsize=3)
             ax.yaxis.label.set_color(text_color)
@@ -916,12 +942,26 @@ class CinacBenchmarks:
             # ax.set_yticklabels([])
             # ax.get_yaxis().set_visible(False)
             # ax.get_xaxis().set_visible(False)
-            # ax.set_ylabel(f"proportion")
+            if put_metric_as_y_axis_label:
+                if title_correspondance is not None and stat_name in title_correspondance:
+                    ax.set_ylabel(title_correspondance[stat_name] + "(%)")
+                else:
+                    ax.set_ylabel(stat_name + "(%)")
+                ax.yaxis.label.set_size(20)
+            else:
+                if title_correspondance is not None and stat_name in title_correspondance:
+                    ax.set_title(title_correspondance[stat_name], color=title_color, pad=20, fontsize=20)
+                else:
+                    ax.set_title(stat_name, color=title_color, pad=20, fontsize=20)
+
             # ax.set_xlabel("age")
             xticks = np.arange(1, n_box_plots + 1)
             ax.set_xticks(xticks)
-            # sce clusters labels
             ax.set_xticklabels(labels)
+
+            yticks = np.arange(0, 1.2, 0.2)
+            ax.set_yticks(yticks)
+            ax.set_yticklabels(np.arange(0, 120, 20))
             # fixing the limits
             if stat_name == "sensitivity":
                 ax.set_ylim(0, 1.1)
@@ -932,11 +972,11 @@ class CinacBenchmarks:
             # elif stat_name == "NPV":
             #     ax.set_ylim(0.6, 1.1)
 
-            ax.set_title(stat_name, color=title_color, pad=20, fontsize=20)
-
         str_details = "frames"
         if not for_frames:
             str_details = "transients"
+        for stat_name in stats_to_show:
+            str_details = str_details + f'_{title_correspondance[stat_name]}'
         if isinstance(save_formats, str):
             save_formats = [save_formats]
         if time_str is None:
@@ -1007,7 +1047,7 @@ class CinacBenchmarks:
                 plt.setp(bplot[element], color="white")
 
             for element in ['means', 'medians']:
-                plt.setp(bplot[element], color="white") # used to be silver
+                plt.setp(bplot[element], color="white")  # used to be silver
 
             if colorfull:
                 colors = colors[:n_box_plots]
@@ -1034,11 +1074,88 @@ class CinacBenchmarks:
                              format=f"{save_format}",
                              facecolor=stat_fig.get_facecolor(), edgecolor='none')
 
+    def stats_on_performance(self, stats_to_evaluate, data_labels=None, title_correspondance=None, for_frames=False):
+        """
+        Compare with a wilcoxon test the performance over all pair of labels (methods)
+        Args:
+            stats_to_evaluate: list of str
+            title_correspondance: dict
+
+        Returns:
+
+        """
+        print("")
+        print("-" * 100)
+        print("COMPARING METRICS values FOR EACH LABEL (Wilcoxon signed-rank test)")
+        result_dict_to_use = self.results_frames_dict
+        if not for_frames:
+            result_dict_to_use = self.results_transients_dict
+
+        for stat_name in stats_to_evaluate:
+            stat_name_to_display = stat_name
+            if (title_correspondance is not None) and (stat_name in title_correspondance):
+                stat_name_to_display = title_correspondance[stat_name]
+            print(f"## For {stat_name_to_display}:")
+            n_labels = len(data_labels)
+            if data_labels is None:
+                data_labels = list(result_dict_to_use.keys())
+
+            values_by_prediction = [[] for n in np.arange(n_labels)]
+            cells_by_prediction = [[] for n in np.arange(n_labels)]
+
+            for label_index, label in enumerate(data_labels):
+                session_dict = result_dict_to_use[label]
+                for session_id, cells_dict in session_dict.items():
+                    for cell_to_display, stat_dict in cells_dict.items():
+                        if stat_name == "F1":
+                            recall = stat_dict["sensitivity"]
+                            precision = stat_dict["PPV"]
+                            if (precision + recall) == 0:
+                                f1_score = 0
+                            else:
+                                f1_score = 2 * ((precision * recall) / (precision + recall))
+                                values_by_prediction[label_index].append(f1_score)
+                        else:
+                            # putting metric value for each cell in the list
+                            values_by_prediction[label_index].append(stat_dict[stat_name])
+                        cells_by_prediction[label_index].append(session_id + "_" + str(cell_to_display))
+
+            for label_index in np.arange(n_labels - 1):
+                for label_index_2 in np.arange(1, n_labels):
+                    if label_index == label_index_2:
+                        continue
+                    values = np.array(values_by_prediction[label_index])
+                    values_2 = np.array(values_by_prediction[label_index_2])
+                    common_cells = np.intersect1d(cells_by_prediction[label_index],
+                                                  cells_by_prediction[label_index_2])
+                    # common_cells = list(set(cells_by_prediction[label_index]) &
+                    #                     set(cells_by_prediction[label_index_2]))
+                    # same cells
+                    if (len(values) != len(values_2)) or len(values) != len(common_cells):
+                        # we only keep common cells
+                        # list of string
+                        cells = cells_by_prediction[label_index]
+                        cells_2 = cells_by_prediction[label_index_2]
+
+                        values = [values[cells.index(cell)] for cell in common_cells]
+                        values_2 = [values_2[cells_2.index(cell)] for cell in common_cells]
+                    sum_of_ranks, p_value = wilcoxon(values, values_2)
+
+                    print(f"{data_labels[label_index]} vs {data_labels[label_index_2]}: p = "
+                          f"{np.round(p_value, 3)}, T = {np.round(sum_of_ranks, 1)}")
+
+            print("")
+
+        print("-" * 100)
+        print("")
+
     def plot_boxplots_f1_score(self, description, colorfull=False, time_str=None,
                                for_frames=True, with_cells=False,
                                color_cell_as_boxplot=False,
                                box_plots_labels=None,
                                white_background=False,
+                               alpha_scatter=1,
+                               put_metric_as_y_axis_label=False,
                                save_formats="pdf", dpi=500):
         """
 
@@ -1120,7 +1237,7 @@ class CinacBenchmarks:
                                    color=color_cell,
                                    marker="o",
                                    edgecolors=edgecolors,
-                                   s=60, zorder=21, alpha=0.4)
+                                   s=60, zorder=21, alpha=alpha_scatter)
                         ax.text(x=x_pos, y=y_pos,
                                 s=f"{cell_to_display}", color="black", zorder=22,
                                 ha='center', va="center", fontsize=font_size, fontweight='bold')
@@ -1145,7 +1262,7 @@ class CinacBenchmarks:
             if white_background:
                 plt.setp(bplot[element], color="black")
             else:
-                plt.setp(bplot[element], color="white") # "silver"
+                plt.setp(bplot[element], color="white")  # "silver"
 
         if colorfull:
             colors = self.colors_boxplots[:n_box_plots]
@@ -1155,10 +1272,11 @@ class CinacBenchmarks:
         ax.xaxis.set_ticks_position('none')
         ax.xaxis.label.set_color(text_color)
         ax.tick_params(axis='x', colors=text_color)
+
         if n_box_plots <= 2:
-            ax.xaxis.set_tick_params(labelsize=15)
+            ax.xaxis.set_tick_params(labelsize=20)
         elif n_box_plots <= 6:
-            ax.xaxis.set_tick_params(labelsize=9)
+            ax.xaxis.set_tick_params(labelsize=15)
         else:
             ax.xaxis.set_tick_params(labelsize=3)
         ax.yaxis.label.set_color(text_color)
@@ -1173,10 +1291,17 @@ class CinacBenchmarks:
         ax.set_xticks(xticks)
         # sce clusters labels
         ax.set_xticklabels(labels)
+        yticks = np.arange(0, 1.2, 0.2)
+        ax.set_yticks(yticks)
+        ax.set_yticklabels(np.arange(0, 120, 20))
         # fixing the limits
         ax.set_ylim(0, 1.1)
 
-        ax.set_title("F1 SCORE", color=title_color, pad=20, fontsize=20)
+        if put_metric_as_y_axis_label:
+            ax.set_ylabel("F1 SCORE" "(%)")
+            ax.yaxis.label.set_size(20)
+        else:
+            ax.set_title("F1 SCORE", color=title_color, pad=20, fontsize=20)
 
         str_details = "frames"
         if not for_frames:
@@ -1298,7 +1423,7 @@ class CinacBenchmarks:
             if white_background:
                 plt.setp(bplot[element], color="black")
             else:
-                plt.setp(bplot[element], color="white") # silver
+                plt.setp(bplot[element], color="white")  # silver
 
         if colorfull:
             colors = self.colors_boxplots[:n_box_plots]
@@ -1500,7 +1625,12 @@ class SessionForBenchmark:
         if "groundtruth" not in yaml_data:
             raise Exception(f"No groundtruth given in {yaml_file_name}")
 
-        for inference_id, inference_data in yaml_data.items():
+        yaml_keys = list(yaml_data.keys())
+        # we want to start by ground_truth
+        yaml_keys.remove("groundtruth")
+        yaml_keys = ["groundtruth"] + yaml_keys
+        for inference_id in yaml_keys:
+            inference_data = yaml_data[inference_id]
             if "cells" not in inference_data:
                 raise Exception(f"Cells are not indicated for {inference_id} of {yaml_file_name}")
             cells = inference_data["cells"]
@@ -1554,6 +1684,7 @@ class SessionForBenchmark:
                     # attribute name in the file (for npz or mat files)
                     attr_name = inference_data.get("attr_name", None)
                     # get a 2d array of shape n_cells*n_frames
+                    print(f"inference_file_name {inference_file_name}")
                     inference_neuronal_data = load_data_from_np_or_mat_file(file_name=inference_file_name,
                                                                             attr_name=attr_name)
                     if "to_bin" in inference_data and inference_data['to_bin']:
@@ -1567,6 +1698,34 @@ class SessionForBenchmark:
                                                                attr_name=traces_attr_name)
                         inference_neuronal_data = get_raster_dur_spikes_and_traces(spike_nums=inference_neuronal_data,
                                                                                    traces=traces)
+
+                    # mapping fiji coord to caiman coord if necessary
+                    if "caiman_fiji_mapping" in inference_data:
+                        print("caiman_fiji_mapping in inference_data")
+                        caiman_fiji_mapping = np.load(
+                            os.path.join(dir_to_explore, inference_data["caiman_fiji_mapping"]))
+                        caiman_raster_dur = np.zeros((self.ground_truth.shape[0], inference_neuronal_data.shape[1]),
+                                                     dtype="int8")
+                        cells_mapped = []
+                        # print(f"caiman_fiji_mapping {caiman_fiji_mapping}")
+                        # caiman_fiji_mapping take a cell index from caiman segmentation
+                        # and return a value > 0 if a cell of Fiji matches (the value is the index of this cell in fiji)
+                        # -1 otherwise
+                        for caiman_cell_index, fiji_cell_index in enumerate(caiman_fiji_mapping):
+                            if fiji_cell_index >= 0:
+                                # print(f"{inference_id}: Cell {fiji_cell_index} -> {caiman_cell_index}")
+                                # using deconvolution value, cell is active if value > 0
+                                caiman_raster_dur[fiji_cell_index] = inference_neuronal_data[caiman_cell_index]
+                                # print(f"sum spikes: {np.sum(caiman_raster_dur[fiji_cell_index])}")
+                                cells_mapped.append(fiji_cell_index)
+                        inference_neuronal_data = caiman_raster_dur
+                        cells_to_keep = []
+                        for cell in cells:
+                            if cell not in cells_mapped:  # caiman_fiji_mapping:
+                                print(f"Cell {cell} has no match in caiman segmentation")
+                            else:
+                                cells_to_keep.append(cell)
+                        cells = np.array(cells_to_keep)
                     self.inferences_raster_dict[inference_id] = [inference_neuronal_data]
                     self.cells_by_inference[inference_id] = cells
                     continue
@@ -1678,7 +1837,7 @@ def do_traces_smoothing(traces):
 
 
 def benchmark_neuronal_activity_inferences(inferences_dir, results_path, colorfull_boxplots=True,
-    white_background=False, color_cell_as_boxplot=False):
+                                           white_background=False, color_cell_as_boxplot=False):
     """
     Evaluate the performances of different inferences methods. Every directory in the main
     directory is considered a session with a ground truth and inferences to benchmark
@@ -1691,7 +1850,6 @@ def benchmark_neuronal_activity_inferences(inferences_dir, results_path, colorfu
     Returns:
 
     """
-    sessions_for_benchmark = []
 
     directories = []
     file_names_in_root = []
@@ -1705,96 +1863,149 @@ def benchmark_neuronal_activity_inferences(inferences_dir, results_path, colorfu
         print(f"No directories with inferences in {inferences_dir}")
         return
 
-    # first getting the main config yaml
-    # list of inference_id, if empty with evaluate all inference, otherwise just those in the list
-    inferences_to_benchmark = []
-    sessions_to_exclude = []
-    # dict that contains as keys a list of keyword allowing to selecting predictions file automatically
-    # the value is the inference_id
-    predictions_keywords_dict = {}
-    default_predictions_threshold = 0.5
-    config_yaml_file = [f for f in file_names_in_root if (not f.startswith(".") and f.endswith(".yaml"))]
-    if len(config_yaml_file) > 0:
-        config_yaml_file = os.path.join(inferences_dir, config_yaml_file[0])
+    config_yaml_files = [f for f in file_names_in_root if (not f.startswith(".") and f.endswith(".yaml"))]
+    if len(config_yaml_files) == 0:
+        print(f"No yaml benchmarks config file in {inferences_dir}")
+        return
+
+    # looping over configuration files and evaluate inference with each config
+    for config_yaml_file in config_yaml_files:
+        sessions_for_benchmark = []
+        # first getting the main config yaml
+        # list of inference_id, if empty with evaluate all inference, otherwise just those in the list
+        inferences_to_benchmark = []
+        sessions_to_exclude = []
+        # dict that contains as keys a list of keyword allowing to selecting predictions file automatically
+        # the value is the inference_id
+        predictions_keywords_dict = {}
+        default_predictions_threshold = 0.5
+
+        config_yaml_file = os.path.join(inferences_dir, config_yaml_file)
         with open(config_yaml_file, 'r') as stream:
             yaml_data = yaml.load(stream, Loader=yaml.FullLoader)
         inferences_to_benchmark = yaml_data.get("inferences_to_benchmark", [])
         sessions_to_exclude = yaml_data.get("sessions_to_exclude", [])
         predictions_keywords_dict = yaml_data.get("predictions_keywords", {})
         default_predictions_threshold = yaml_data.get("predictions_threshold", 0.5)
+        # allows to create a subdirecoty to put the results
+        config_id = yaml_data.get("config_id", None)
 
-    directories = [os.path.join(inferences_dir, d) for d in directories if not d.startswith(".")]
+        if config_id is None:
+            config_results_path = results_path
+        else:
+            # create a directory
+            config_results_path = os.path.join(results_path, config_id)
+            os.mkdir(config_results_path)
 
-    inference_ids = []
+        directories = [os.path.join(inferences_dir, d) for d in directories if not d.startswith(".")]
 
-    for dir_to_explore in directories:
-        if os.path.basename(dir_to_explore) in sessions_to_exclude:
-            # excluding the session evaluation
-            continue
+        inference_ids = []
 
-        session_for_benchmark = SessionForBenchmark(dir_to_explore=dir_to_explore,
-                                                    inferences_to_benchmark=inferences_to_benchmark,
-                                                    predictions_keywords_dict=predictions_keywords_dict,
-                                                    default_predictions_threshold=default_predictions_threshold)
-        if session_for_benchmark.valid:
-            sessions_for_benchmark.append(session_for_benchmark)
-            inference_ids.extend(session_for_benchmark.get_inference_ids())
+        for dir_to_explore in directories:
+            if os.path.basename(dir_to_explore) in sessions_to_exclude:
+                # excluding the session evaluation
+                continue
 
-    # making it unique
-    inference_ids = set(inference_ids)
-    colors_boxplots = ['#a6cee3', '#1f78b4', '#b2df8a', '#33a02c', '#fb9a99', '#e31a1c',
-                       '#ff7f00', '#cab2d6', '#fdbf6f', '#6a3d9a', '#ffff99', '#b15928', '#ffffd9']
-    cinac_benchmarks = CinacBenchmarks(results_path=results_path, colors_boxplots=colors_boxplots)
+            session_for_benchmark = SessionForBenchmark(dir_to_explore=dir_to_explore,
+                                                        inferences_to_benchmark=inferences_to_benchmark,
+                                                        predictions_keywords_dict=predictions_keywords_dict,
+                                                        default_predictions_threshold=default_predictions_threshold)
+            if session_for_benchmark.valid:
+                sessions_for_benchmark.append(session_for_benchmark)
+                inference_ids.extend(session_for_benchmark.get_inference_ids())
 
-    description = ""
-    for session_index, session_for_benchmark in enumerate(sessions_for_benchmark):
-        description = description + session_for_benchmark.session_id + "_"
-        session_for_benchmark.add_it_to_cinac_benchmark(cinac_benchmarks=cinac_benchmarks)
-        cinac_benchmarks.color_by_session(session_id=session_for_benchmark.session_id,
-                                          color=BREWER_COLORS[session_index % len(BREWER_COLORS)])
+        # making it unique
+        inference_ids = set(inference_ids)
+        colors_boxplots = ['#a6cee3', '#1f78b4', '#b2df8a', '#33a02c', '#fb9a99', '#e31a1c',
+                           '#ff7f00', '#cab2d6', '#fdbf6f', '#6a3d9a', '#ffff99', '#b15928', '#ffffd9']
+        cinac_benchmarks = CinacBenchmarks(results_path=config_results_path, colors_boxplots=colors_boxplots)
 
-    cinac_benchmarks.evaluate_metrics()
+        description = ""
+        for session_index, session_for_benchmark in enumerate(sessions_for_benchmark):
+            description = description + session_for_benchmark.session_id + "_"
+            session_for_benchmark.add_it_to_cinac_benchmark(cinac_benchmarks=cinac_benchmarks)
+            cinac_benchmarks.color_by_session(session_id=session_for_benchmark.session_id,
+                                              color=BREWER_COLORS[session_index % len(BREWER_COLORS)])
 
-    time_str = datetime.now().strftime("%Y_%m_%d.%H-%M-%S")
+        cinac_benchmarks.evaluate_metrics()
 
-    # ploting benchmarks
-    # TODO: to fix, works for one prediction file only
-    # cinac_benchmarks.plot_boxplot_predictions_stat_by_metrics(description=description, time_str=time_str,
-    #                                                           colorfull=colorfull_boxplots,
-    #                                                           white_background=white_background,
-    #                                                           save_formats=["png"])
+        time_str = datetime.now().strftime("%Y_%m_%d.%H-%M-%S")
 
-    # only transients
-    for for_frames in [False]:
-        cinac_benchmarks.plot_boxplots_full_stat(description=description, time_str=time_str,
-                                                 colorfull=colorfull_boxplots,
-                                                 color_cell_as_boxplot=color_cell_as_boxplot,
-                                                 box_plots_labels=inferences_to_benchmark,
-                                                 white_background=white_background,
-                                                 for_frames=for_frames, save_formats=["png"], with_cells=True, dpi=300)
+        # ploting benchmarks
+        # TODO: to fix, works for one prediction file only
+        # cinac_benchmarks.plot_boxplot_predictions_stat_by_metrics(description=description, time_str=time_str,
+        #                                                           colorfull=colorfull_boxplots,
+        #                                                           white_background=white_background,
+        #                                                           save_formats=["png"])
 
-        cinac_benchmarks.plot_boxplots_f1_score(description=description, time_str=time_str,
-                                                colorfull=colorfull_boxplots,
-                                                color_cell_as_boxplot=color_cell_as_boxplot,
-                                                box_plots_labels=inferences_to_benchmark,
-                                                white_background=white_background,
-                                                for_frames=for_frames, save_formats=["png"], with_cells=True, dpi=300)
+        # only transients
+        for for_frames in [False]:
+            # cinac_benchmarks.plot_boxplots_full_stat(description=description, time_str=time_str,
+            #                                          colorfull=colorfull_boxplots,
+            #                                          color_cell_as_boxplot=color_cell_as_boxplot,
+            #                                          box_plots_labels=inferences_to_benchmark,
+            #                                          white_background=white_background,
+            #                                          stats_to_show=("sensitivity", "PPV"),
+            #                                          title_correspondance={"sensitivity": "Sensitivity",
+            #                                                                "PPV": "Precision"},
+            #                                          for_frames=for_frames, save_formats=["png"], with_cells=True,
+            #                                          alpha_scatter=0.8,
+            #                                          dpi=500)
 
-    # cinac_benchmarks.plot_boxplots_proportion_frames_in_transients(description=description,
-    #                                                                time_str=time_str,
-    #                                                                only_this_key=None,
-    #                                                                colorfull=colorfull_boxplots,
-    #                                                                white_background=white_background,
-    #                                                                with_scatter=True,
-    #                                                                with_cell_text=False,
-    #                                                                save_formats="png", dpi=300)
+            cinac_benchmarks.stats_on_performance(stats_to_evaluate=["sensitivity", "PPV", "F1"],
+                                                  data_labels=inferences_to_benchmark,
+                                                  title_correspondance={"PPV": "Precision",
+                                                                        "sensitivity": "Sensitivity"})
 
-    # for inference_id in inference_ids:
-    #     cinac_benchmarks.plot_boxplots_proportion_frames_in_transients(description=description,
-    #                                                                    time_str=time_str,
-    #                                                                    only_this_key=inference_id,
-    #                                                                    colorfull=colorfull_boxplots,
-    #                                                                    white_background=white_background,
-    #                                                                    with_scatter=True,
-    #                                                                    with_cell_text=False,
-    #                                                                    save_formats="png", dpi=500)
+            cinac_benchmarks.plot_boxplots_full_stat(description=description, time_str=time_str,
+                                                     colorfull=colorfull_boxplots,
+                                                     color_cell_as_boxplot=color_cell_as_boxplot,
+                                                     box_plots_labels=inferences_to_benchmark,
+                                                     white_background=white_background,
+                                                     stats_to_show=["sensitivity"],
+                                                     title_correspondance={"sensitivity": "Sensitivity"},
+                                                     for_frames=for_frames, save_formats=["png"], with_cells=True,
+                                                     put_metric_as_y_axis_label=False,
+                                                     alpha_scatter=0.8,
+                                                     dpi=500)
+
+            cinac_benchmarks.plot_boxplots_full_stat(description=description, time_str=time_str,
+                                                     colorfull=colorfull_boxplots,
+                                                     color_cell_as_boxplot=color_cell_as_boxplot,
+                                                     box_plots_labels=inferences_to_benchmark,
+                                                     white_background=white_background,
+                                                     stats_to_show=["PPV"],
+                                                     title_correspondance={"PPV": "Precision"},
+                                                     for_frames=for_frames, save_formats=["png"], with_cells=True,
+                                                     put_metric_as_y_axis_label=False,
+                                                     alpha_scatter=0.8,
+                                                     dpi=500)
+
+            cinac_benchmarks.plot_boxplots_f1_score(description=description, time_str=time_str,
+                                                    colorfull=colorfull_boxplots,
+                                                    color_cell_as_boxplot=color_cell_as_boxplot,
+                                                    box_plots_labels=inferences_to_benchmark,
+                                                    white_background=white_background,
+                                                    alpha_scatter=0.8,
+                                                    for_frames=for_frames, save_formats=["png"], with_cells=True,
+                                                    put_metric_as_y_axis_label=False,
+                                                    dpi=500)
+
+        # cinac_benchmarks.plot_boxplots_proportion_frames_in_transients(description=description,
+        #                                                                time_str=time_str,
+        #                                                                only_this_key=None,
+        #                                                                colorfull=colorfull_boxplots,
+        #                                                                white_background=white_background,
+        #                                                                with_scatter=True,
+        #                                                                with_cell_text=False,
+        #                                                                save_formats="png", dpi=300)
+
+        # for inference_id in inference_ids:
+        #     cinac_benchmarks.plot_boxplots_proportion_frames_in_transients(description=description,
+        #                                                                    time_str=time_str,
+        #                                                                    only_this_key=inference_id,
+        #                                                                    colorfull=colorfull_boxplots,
+        #                                                                    white_background=white_background,
+        #                                                                    with_scatter=True,
+        #                                                                    with_cell_text=False,
+        #                                                                    save_formats="png", dpi=500)
