@@ -91,6 +91,7 @@ class CinacPredictor:
 
     def predict(self, results_path, overlap_value=0.5, output_file_formats="npy", cell_type_classifier_mode=False,
                 n_segments_to_use_for_prediction=2, cell_type_pred_fct=np.mean, create_dir_for_results=True,
+                cell_buffer=None, all_pixels=False,
                 **kwargs):
         """
         Will predict the neural activity state of the cell for each frame of the calcium imaging movies.
@@ -110,6 +111,9 @@ class CinacPredictor:
             cell_type_pred_fct: fct to use to average the predictons if it is done in more than one segment
             create_dir_for_results: if True, create a dir with timestamps to store the results. The directory is created
             in results_path. Else predictions are stored directly in results_path
+            cell_buffer: None or int, distance in order to transform the cell contour giving an approximate
+            representation of  all points within a given distance of the this geometric object
+            all_pixels: bool, use for cell type prediction, add input with all pixels
             **kwargs:
 
 
@@ -187,6 +191,7 @@ class CinacPredictor:
                                                                    cell=cell, model=model, overlap_value=overlap_value,
                                                                    use_data_augmentation=use_data_augmentation,
                                                                    n_frames=n_frames,
+                                                                   all_pixels=all_pixels,
                                                                    n_segments_to_use_for_prediction=
                                                                    n_segments_to_use_for_prediction,
                                                                    verbose=self.verbose)
@@ -209,7 +214,7 @@ class CinacPredictor:
                         predictions = predict_transient_from_model(cinac_recording=cinac_recording,
                                                                    cell=cell, model=model, overlap_value=overlap_value,
                                                                    use_data_augmentation=use_data_augmentation,
-                                                                   n_frames=n_frames, buffer=1, pixels_around=0)
+                                                                   n_frames=n_frames, buffer=cell_buffer, pixels_around=0)
                         # print(f"### cinac_predictor predict(): np.sum(predictions) {np.sum(predictions)}")
                         if len(predictions.shape) == 1:
                             predictions_by_cell[original_cell] = predictions
@@ -266,7 +271,7 @@ class CinacPredictor:
 
 def predict_cell_type_from_model(cinac_recording, cell, model,
                                  n_frames, n_segments_to_use_for_prediction=2,
-                                 overlap_value=0, pixels_around=0,
+                                 overlap_value=0, pixels_around=0, all_pixels=False,
                                  use_data_augmentation=False, buffer=None, verbose=0):
     # if n_frames is None, then the movie need to have been loaded
     # start_time = time.time()
@@ -299,9 +304,10 @@ def predict_cell_type_from_model(cinac_recording, cell, model,
 
     movie_patch_generator = \
         MoviePatchGeneratorForCellType(window_len=window_len, max_width=max_width, max_height=max_height,
-                                       pixels_around=pixels_around, buffer=buffer, with_all_pixels=False,
+                                       pixels_around=pixels_around, buffer=buffer, with_all_pixels=all_pixels,
                                        using_multi_class=using_multi_class, cell_type_classifier_mode=True)
 
+    # print(f"Cell {cell} from {cinac_recording.identifier}")
     data_dict = movie_patch_generator.generate_movies_from_metadata(movie_data_list=movie_patches,
                                                                     with_labels=False)
 
@@ -757,7 +763,8 @@ def activity_predictions_from_cinac_files(cinac_dir_name, results_path,
 
 
 def evaluate_cell_type_predictions(cinac_dir_name, cell_type_yaml_file, results_path,
-                                   json_file_name, weights_file_name, save_cell_type_distribution):
+                                   json_file_name, weights_file_name, save_cell_type_distribution, all_pixels=False
+                                   ):
     """
     Evaluation the cell type prediction on cinac file with ground truth.
     Load all cinac files from a folder and compare the predictions from the classifier to the cell type in the cinac
@@ -771,6 +778,7 @@ def evaluate_cell_type_predictions(cinac_dir_name, cell_type_yaml_file, results_
         weights_file_name: .h5 file containing the weights of the network to classify the cell types
         save_cell_type_distribution: (bool) if True, a figure representing the distribution of the predictions score
         of each cell type will be save in results_path
+        all_pixels: if True, add an input with all pixels in the frame
 
     Returns:
 
@@ -898,7 +906,8 @@ def evaluate_cell_type_predictions(cinac_dir_name, cell_type_yaml_file, results_
                                                        overlap_value=0, cell_type_classifier_mode=True,
                                                        n_segments_to_use_for_prediction=4,
                                                        cell_type_pred_fct=np.mean,
-                                                       create_dir_for_results=False)
+                                                       create_dir_for_results=False,
+                                                       all_pixels=all_pixels)
             # mean of the different predictions is already in the dict
             prediction_value = predictions_dict[list(predictions_dict.keys())[0]][0]
 
