@@ -526,7 +526,6 @@ def get_source_profile_param(cell, movie_dimensions, coord_obj, max_width, max_h
     cells_to_display.extend(overlapping_cells)
 
     # calculating the bound that will surround all the cells
-
     # if the size of the frame already matches the max dimensions, then we keep it that way
     if (len_frame_y == max_width) and (len_frame_x == max_height):
         minx = 0
@@ -658,7 +657,10 @@ def get_source_profile_param(cell, movie_dimensions, coord_obj, max_width, max_h
         polygon = coord_obj.cells_polygon[cell_to_display]
         # mask used in order to keep only the cells pixel
         # the mask put all pixels in the polygon, including the pixels on the exterior line to zero
-        scaled_polygon = scale_polygon_to_source(polygon=polygon, minx=minx, miny=miny)
+        if minx == 0 and miny == 0:
+            scaled_polygon = polygon
+        else:
+            scaled_polygon = scale_polygon_to_source(polygon=polygon, minx=minx, miny=miny)
         img = PIL.Image.new('1', (len_x, len_y), 1)
         if buffer is not None:
             scaled_polygon = scaled_polygon.buffer(buffer)
